@@ -8,6 +8,7 @@ from datetime import datetime
 
 from django.conf import settings
 from django.core.management.base import BaseCommand
+from django.db import connection
 from edx_django_utils.monitoring import record_exception, set_custom_attribute
 from edx_toggles.toggles import SettingToggle
 from openedx_events.event_bus.avro.deserializer import AvroSignalDeserializer
@@ -74,6 +75,16 @@ class ReceiverError(Exception):
         self.causes = causes  # just used for testing
 
 
+def _reconnect_to_db_if_needed():
+    """
+    Reconnects the db connection if needed.
+    """
+    has_connection = bool(connection.connection)
+    requires_reconnect = has_connection and not connection.is_usable()
+    if requires_reconnect:
+        connection.connect()
+
+
 class KafkaEventConsumer:
     """
     Construct consumer for the given topic, group, and signal. The consumer can then
@@ -234,6 +245,9 @@ class KafkaEventConsumer:
                 try:
                     msg = self.consumer.poll(timeout=CONSUMER_POLL_TIMEOUT)
                     if msg is not None:
+                        # Before processing, make sure our db connection is still active
+                        _reconnect_to_db_if_needed()
+
                         self.emit_signals_from_message(msg)
                         consecutive_errors = 0
 
